@@ -583,6 +583,10 @@ class Moon(models.Model):
         except (ObjectDoesNotExist, AttributeError):
             return type(self).objects.none()
 
+    @property
+    def rarity_class_str(self) -> str:
+        return OreRarityClass(self.rarity_class).label
+
     @property
     def rarity_tag_html(self) -> str:
         return OreRarityClass(self.rarity_class).bootstrap_tag_html
